<?php

namespace Drupal\tapis_tenant\Exception;

/**
 * {@inheritDoc}
 */
class TapisException extends \Exception {
  /**
   * The primary exception message.
   *
   * @var string
   */
  protected string $primaryMessage;

  /**
   * Reload the same page.
   *
   * @var bool
   */
  protected bool $reloadSamePage;

  /**
   * Constructs a new TapisException.
   *
   * @param string $message
   *   The exception message.
   * @param int $code
   *   The exception code.
   * @param \Throwable|null $previous
   *   The previous exception used for the exception chaining.
   * @param null $primaryMessage
   *   The primary exception message.
   * @param bool $reload_same_page
   *   Reload the same page.
   */
  public function __construct(
        string $message,
        int $code = 0,
        \Throwable $previous = NULL,
        $primaryMessage = NULL,
        bool $reload_same_page = FALSE
    ) {
    parent::__construct($message, $code, $previous);
    $this->primaryMessage = $primaryMessage;
    $this->reloadSamePage = $reload_same_page;
  }

  /**
   * Returns the exception message.
   *
   * @return string|null
   *   The exception message.
   */
  public function getPrimaryMessage(): ?string {
    return $this->primaryMessage;
  }

  /**
   * Set the primary message.
   */
  public function setPrimaryMessage($primaryMessage): void {
    $this->primaryMessage = $primaryMessage;
  }

  /**
   * Set the reload same page.
   */
  public function setReloadSamePage($reloadSamePage): void {
    $this->reloadSamePage = $reloadSamePage;
  }

  /**
   * Returns the reload same page.
   *
   * @return bool
   *   The reload same page.
   */
  public function shouldReloadSamePage(): bool {
    return $this->reloadSamePage;
  }

}
